import { Action, StateOrCallback } from './models';
export declare const enum MiniRxActionType {
    INIT = "init",
    DESTROY = "destroy",
    SET_STATE = "set-state"
}
export declare const enum SetStateActionType {
    FEATURE_STORE = "@mini-rx/feature-store",
    COMPONENT_STORE = "@mini-rx/component-store"
}
export interface FeatureStoreSetStateAction<T> {
    setStateActionType: SetStateActionType.FEATURE_STORE;
    stateOrCallback: StateOrCallback<T>;
    type: string;
    featureId: string;
    featureKey: string;
}
export interface ComponentStoreSetStateAction<T> {
    setStateActionType: SetStateActionType.COMPONENT_STORE;
    stateOrCallback: StateOrCallback<T>;
    type: string;
}
export declare type SetStateAction<T> = FeatureStoreSetStateAction<T> | ComponentStoreSetStateAction<T>;
export declare function createMiniRxActionType(miniRxActionType: MiniRxActionType, featureKey?: string): string;
export declare function createMiniRxAction(miniRxActionType: MiniRxActionType.INIT | MiniRxActionType.DESTROY, featureKey?: string): Action;
export declare function isFeatureStoreSetStateAction<StateType>(action: Action): action is FeatureStoreSetStateAction<StateType>;
export declare function isComponentStoreSetStateAction<StateType>(action: Action): action is ComponentStoreSetStateAction<StateType>;
export declare const UNDO_ACTION: string;
export declare function undo(action: Action): {
    type: string;
    payload: Action;
};
