import { Observable } from 'rxjs';
export declare const enum ExtensionSortOrder {
    DEFAULT = 0,
    UNDO_EXTENSION = 1
}
export declare type AppState = Record<string, any>;
export declare const enum ExtensionId {
    IMMUTABLE_STATE = 0,
    UNDO = 1,
    LOGGER = 2,
    REDUX_DEVTOOLS = 3
}
export declare abstract class StoreExtension {
    abstract id: ExtensionId;
    sortOrder: ExtensionSortOrder;
    abstract init(): MetaReducer<any> | void;
}
export interface HasComponentStoreSupport {
    hasCsSupport: true;
    init(): MetaReducer<any>;
}
export declare type ComponentStoreExtension = StoreExtension & HasComponentStoreSupport;
export interface ComponentStoreConfig {
    extensions: ComponentStoreExtension[];
}
export interface Action {
    type: string;
    [x: string]: any;
}
export interface ActionWithPayload extends Action {
    payload?: any;
}
export interface StoreConfig<T> {
    reducers: ReducerDictionary<T>;
    initialState: T;
    metaReducers: MetaReducer<AppState>[];
    extensions: StoreExtension[];
    combineReducersFn: CombineReducersFn<AppState>;
}
export interface FeatureConfig<StateType> {
    initialState: StateType;
    metaReducers?: MetaReducer<StateType>[];
}
export interface FeatureStoreConfig {
    multi?: boolean;
}
export declare class Actions extends Observable<Action> {
}
export declare type Reducer<StateType> = (state: StateType, action: Action) => StateType;
export declare type MetaReducer<StateType> = (reducer: Reducer<StateType>) => Reducer<StateType>;
export declare type ReducerDictionary<T> = {
    [p in keyof T]: Reducer<T[p]>;
};
export declare type CombineReducersFn<T> = (reducers: ReducerDictionary<T>) => Reducer<T>;
export declare type StateOrCallback<StateType> = Partial<StateType> | ((state: StateType) => Partial<StateType>);
export declare const EFFECT_METADATA_KEY = "@mini-rx/effectMetaData";
export interface EffectConfig {
    /**
     * Determines if the action emitted by the effect is dispatched to the store.
     * If false, effect does not need to return type `Observable<Action>`.
     */
    dispatch?: boolean;
}
export interface HasEffectMetadata {
    [EFFECT_METADATA_KEY]: EffectConfig;
}
export declare type SetStateParam<T> = StateOrCallback<T> | Observable<Partial<T>>;
export declare type SetStateReturn<T, P extends SetStateParam<T>> = P extends Observable<Partial<T>> ? void : Action;
export interface ComponentStoreLike<StateType> {
    setInitialState(initialState: StateType): void;
    setState(stateOrCallback: SetStateParam<StateType>, name?: string): void;
    get state(): StateType;
    select(mapFn?: any): Observable<any>;
    effect(effectFn: (origin$: Observable<any>) => Observable<any>): () => void;
    undo(action: Action): void;
    destroy(): void;
}
